function [R_n, T_n] = MRL_RNMRL(thetas)
%
% This source code was published as supporting material for the article:
% Ralph G. Andrzejak, Anas Espinoso, Eduardo Garca-Portugus, 
% Arthur Pewsey, Jacopo Epifanio, Marc G. Leguia, Kaspar Schindler; 
% High expectations on phase locking: Better quantifying the concentration 
% of circular data. Chaos (2023); 33 (9): 091106. 
% https://doi.org/10.1063/5.0166468
%
% If you have no access to this journal page, please visit the repository
% of our university at:
% https://doi.org/10.34810/data845
% Which contains links to a reprint.
%
%
% This function determines the mean resultant length R_n (Eq. 1) and 
% re-normalized mean resultant length T_n (Eq. 5) 
% using the expected value gamma_n (Eq. 4)
% for a set of phases provided as input thetas.
%
% Please note again: 
% We here encapsulate the calculation of the mean resultant length and re-
% normalized mean resultant length in this function. 
% This makes it easy to understand and easy to use. 
% However, if you need to compute it for larger data, such as the temporal 
% profiles shown in the figure and if execution time matters, 
% you can use the matlab typical matrix calculus and avoid that the sample 
% size n and gamma_n are determined for every new sample of phases.

n = length(thetas);
R_n = abs(1/n*(sum(exp(1i*thetas))));
gamma_n = 1/2*sqrt(pi/n);
T_n = (R_n-gamma_n)/(1-gamma_n);